@@ -1,4 +1,6 @@
 #!/usr/bin/env python3
+"""Python documentation generator using GitHub Copilot CLI."""
+
 import logging
 import os
 import ast
@@ -17,63 +19,39 @@ logger = logging.getLogger('python_copilot_docs_hook')
 def get_copilot_suggestion(code: str) -> str:
     """Get documentation suggestion using GitHub Copilot CLI."""
     try:
-        # Try direct suggestion first
-        suggestion = _try_copilot_command(
-            ['gh', 'copilot', 'suggest'],
-            f"Write a Python docstring for this code:\n\n{code}"
-        )
-        if suggestion:
-            return format_suggestion(suggestion)
-
-        # Try explain command
-        suggestion = _try_copilot_command(
-            ['gh', 'copilot', 'explain'],
-            code
-        )
-        if suggestion:
-            return format_suggestion(suggestion)
-
-        # Try completion as last resort
-        suggestion = _try_copilot_command(
-            ['gh', 'copilot', 'completion'],
-            f'"""\nWrite a complete docstring for this Python code:\n{code}\n"""'
-        )
-        if suggestion:
-            return format_suggestion(suggestion)
-
-        return ""
-
-    except Exception as e:
-        logger.error(f"Error getting Copilot suggestion: {e}")
-        return ""
-
-def _try_copilot_command(command: List[str], input_text: str, additional_args: List[str] = None) -> Optional[str]:
-    """Execute a GitHub Copilot CLI command with proper error handling."""
-    try:
-        cmd = command + (additional_args or [])
-        logger.debug(f"Trying command: {' '.join(cmd)}")
-        
-        # Run command with input through stdin
+        # Try interactive suggestion
         result = subprocess.run(
-            cmd,
-            input=input_text,
+            ['gh', 'copilot', 'suggest'],
+            input=f"Write a Python docstring for:\n{code}",
             capture_output=True,
             text=True,
-            check=False  # Don't raise exception on non-zero exit
+            check=False
         )
         
         if result.returncode == 0 and result.stdout:
-            return result.stdout
+            return format_suggestion(result.stdout)
+
+        logger.debug(f"Suggest command failed: {result.stderr}")
         
-        if result.stderr:
-            logger.debug(f"Command failed: {result.stderr}")
-        
-        return None
-            
+        # Try explain command
+        result = subprocess.run(
+            ['gh', 'copilot', 'explain'],
+            input=code,
+            capture_output=True,
+            text=True,
+            check=False
+        )
+
+        if result.returncode == 0 and result.stdout:
+            return format_suggestion(result.stdout)
+
+        logger.debug(f"Explain command failed: {result.stderr}")
+
     except Exception as e:
-        logger.debug(f"Command execution failed: {e}")
-        return None
-    
+        logger.error(f"Error getting Copilot suggestion: {e}")
+
+    return ""
+
 def format_suggestion(text: str) -> str:
     """Format Copilot output as a proper docstring."""
     lines = []
@@ -107,52 +85,93 @@ def format_suggestion(text: str) -> str:
             lines.append(f"    {ret_desc}")
             lines.append("")
 
+    # Process exceptions
+    for para in paragraphs:
+        if "Raises:" in para:
+            lines.append("Raises:")
+            for line in para.split('\n')[1:]:
+                if ':' in line:
+                    exc, desc = line.split(':', 1)
+                    lines.append(f"    {exc.strip()}: {desc.strip()}")
+                elif line.strip():
+                    lines.append(f"    {line.strip()}")
+            lines.append("")
+
     return "\n".join(lines).strip()
 
+def validate_file(filename: str) -> bool:
+    """Validate Python file before processing."""
+    if not os.path.isfile(filename):
+        logger.error(f"File not found: {filename}")
+        return False
+        
+    if not filename.endswith('.py'):
+        logger.error(f"Not a Python file: {filename}")
+        return False
+        
+    return True
+
 def update_file_with_docs(filename: str) -> bool:
     """Update Python file with generated documentation."""
-    with open(filename, 'r', encoding='utf-8') as f:
-        content = f.read()
-
-    try:
-        tree = ast.parse(content)
-    except SyntaxError:
-        logger.error(f"Syntax error in file: {filename}")
+    if not validate_file(filename):
         return False
 
-    modified = False
+    try:
+        # Read file content
+        with open(filename, 'r', encoding='utf-8') as f:
+            content = f.read().strip()
 
-    # Generate module docstring if missing
-    if not ast.get_docstring(tree):
-        logger.debug("Generating module docstring")
-        module_doc = get_copilot_suggestion(content)
-        if module_doc:
-            content = f'"""{module_doc}"""\n\n{content}'
-            modified = True
+        # Parse Python code
+        try:
+            tree = ast.parse(content)
+        except SyntaxError as e:
+            lines = content.splitlines()
+            if 0 <= e.lineno - 1 < len(lines):
+                problematic_line = lines[e.lineno - 1]
+                logger.error(f"Syntax error in file {filename}:")
+                logger.error(f"Line {e.lineno}: {problematic_line}")
+                logger.error(f"Error: {e.msg}")
+                logger.error(" " * (e.offset + 7) + "^")
+            else:
+                logger.error(f"Syntax error in file {filename} at line {e.lineno}: {e.msg}")
+            return False
 
-    # Find and generate function docstrings
-    for node in ast.walk(tree):
-        if isinstance(node, ast.FunctionDef) and not ast.get_docstring(node):
-            logger.debug(f"Generating docstring for function: {node.name}")
-            func_code = ast.get_source_segment(content, node)
-            doc = get_copilot_suggestion(func_code)
-            
-            if doc:
-                # Insert docstring after function definition
-                lines = content.splitlines()
-                indent = ' ' * node.col_offset
-                doc_lines = [f'{indent}    """{line}"""' for line in doc.splitlines()]
-                lines.insert(node.lineno, '\n'.join(doc_lines))
-                content = '\n'.join(lines)
+        modified = False
+        
+        # Generate module docstring if missing
+        if not ast.get_docstring(tree):
+            logger.debug("Generating module docstring")
+            module_doc = get_copilot_suggestion(content)
+            if module_doc:
+                content = f'"""{module_doc}"""\n\n{content}'
                 modified = True
 
-    # Write changes if any modifications were made
-    if modified:
-        logger.info(f"Updating file with generated documentation: {filename}")
-        with open(filename, 'w', encoding='utf-8') as f:
-            f.write(content)
+        # Find and generate function docstrings
+        for node in ast.walk(tree):
+            if isinstance(node, ast.FunctionDef) and not ast.get_docstring(node):
+                logger.debug(f"Generating docstring for function: {node.name}")
+                func_code = ast.get_source_segment(content, node)
+                doc = get_copilot_suggestion(func_code)
+                
+                if doc:
+                    lines = content.splitlines()
+                    indent = ' ' * node.col_offset
+                    doc_lines = [f'{indent}    """{line}"""' for line in doc.splitlines()]
+                    lines.insert(node.lineno, '\n'.join(doc_lines))
+                    content = '\n'.join(lines)
+                    modified = True
 
-    return True
+        # Write changes if modified
+        if modified:
+            with open(filename, 'w', encoding='utf-8') as f:
+                f.write(content)
+            logger.info(f"Updated documentation in {filename}")
+
+        return True
+
+    except Exception as e:
+        logger.error(f"Error processing file {filename}: {e}")
+        return False
 
 def main() -> int:
     """Process Python files and add missing documentation."""
@@ -163,7 +182,7 @@ def main() -> int:
     args = parser.parse_args()
 
     try:
-        # Check if gh CLI and Copilot extension are available
+        # Verify GitHub CLI and Copilot extension
         try:
             subprocess.run(['gh', '--version'], check=True, capture_output=True)
             subprocess.run(['gh', 'copilot', '--version'], check=True, capture_output=True)
@@ -174,13 +193,12 @@ def main() -> int:
             logger.error("3. gh auth login")
             return 1
 
-        # Process each Python file
+        # Process files
         exit_code = 0
         for filename in args.filenames:
-            if filename.endswith('.py'):
-                logger.debug(f"Processing file: {filename}")
-                if not update_file_with_docs(filename):
-                    exit_code = 1
+            logger.debug(f"Processing file: {filename}")
+            if not update_file_with_docs(filename):
+                exit_code = 1
 
         return exit_code
 
